#
# spec file for package xfce4-session
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libxfsm-4_6-0

Name:           xfce4-session
Version:        4.12.1
Release:        lp150.3.7
Summary:        Xfce Session Manager
License:        GPL-2.0
Group:          System/GUI/XFCE
Url:            http://docs.xfce.org/xfce/xfce4-session/start
Source0:        http://archive.xfce.org/src/xfce/xfce4-session/4.12/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE xfce4-session-simple-splash-remove-shadows.patch gber@opensuse.org -- Improves readability of the simple splash engine text by removing the text shadows
Patch0:         xfce4-session-simple-splash-remove-shadows.patch
# PATCH-FIX-OPENSUSE xfce4-session-adapt-session-scripts.patch bnc#789057 gber@opensuse.org -- Adapt upstream sessions script to openSUSE
Patch1:         xfce4-session-adapt-session-scripts.patch
# PATCH-FIX-UPSTREAM xfce4-session-Make-verbose-logging-conditional.patch boo#999676
Patch2:         xfce4-session-Make-verbose-logging-conditional.patch
# PATCH-FIX-OPENSUSE xfce4-session-systemd-user-addons.patch seife+dev@b1-systems.com -- fix systemd-user session settings
Patch3:         xfce4-session-systemd-user-addons.patch
BuildRequires:  iceauth
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libwnck-1.0)
BuildRequires:  pkgconfig(libxfce4panel-1.0)
BuildRequires:  pkgconfig(libxfce4ui-1)
BuildRequires:  pkgconfig(libxfce4util-1.0)
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.100
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(atk)
Requires:       %{name}-branding = %{version}
Requires:       systemd
Requires:       xfce4-settings
Requires:       xfconf
# bnc#845264
Requires:       iceauth
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{name}-doc = %{version}
Recommends:     %{name}-lang = %{version}
# minimal packages for an Xfce session
Recommends:     xfwm4
Recommends:     xfdesktop
Recommends:     thunar
Recommends:     xfce4-panel
# xfce4-about needs to be dragged at a low level
Recommends:     libxfce4ui-tools
Provides:       xfce-utils = %{version}
Obsoletes:      xfce-utils <= 4.8.3
Provides:       xfce-utils-doc = %{version}
Obsoletes:      xfce-utils-doc <= 4.8.3
Provides:       xfce-utils-lang = %{version}
Obsoletes:      xfce-utils-lang <= 4.8.3
Provides:       xfce4-session-doc = %{version}
Obsoletes:      xfce4-session-doc <= 4.8.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
xfce4-session is the session manager for the Xfce desktop environment.

%package -n %{libname}
Summary:        Shared Library for xfce4-session Splash Screen Engines
Group:          System/Libraries

%description -n %{libname}
This package contains the shared library for xfce4-session splash screen
engines.

%package        devel
Summary:        Development Files for xfce4-session
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package contains development files needed to develop custom splash screen
engines for the xfce4-session.

%package branding-upstream
Summary:        Upstream Branding of xfce4-session
Group:          System/GUI/XFCE
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
# BRAND: xfce4-session.xml: Control session parameters such as the tools and
# BRAND: applications started by default or the splash theme.
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for the Xfce Session Manager.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
xdt-autogen
%configure \
    --disable-static
make %{?_smp_mflags} V=1

%install
%make_install

chmod 755 %{buildroot}%{_sysconfdir}/xdg/xfce4/xinitrc

install -d -m 755 %{buildroot}%{_datadir}/xfce/applications

# add back X-XFCE for now; this is a personal and not a system setting
%suse_update_desktop_file -r xfce-session-settings XFCE X-XFCE GTK Settings DesktopSettings X-XFCE-SettingsDialog X-XFCE-PersonalSettings
%suse_update_desktop_file xfce4-session-logout

%find_lang %{name}

find %{buildroot} -type f -name "*.la" -delete -print
# not needed, shutdown/reboot happens via systemd
rm %{buildroot}%{_datadir}/polkit-1/actions/org.xfce.session.policy \
    %{buildroot}%{_libdir}/xfce4/session/xfsm-shutdown-helper

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%post
%desktop_database_post
%icon_theme_cache_post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/xfce.desktop 20

%postun
%desktop_database_postun
%icon_theme_cache_postun
[ -f %{_datadir}/xsessions/xfce.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/xfce.desktop

%files
%defattr(-,root,root)
%doc AUTHORS BUGS COPYING ChangeLog NEWS README TODO
%dir %{_sysconfdir}/xdg/xfce4
%config %{_sysconfdir}/xdg/xfce4/Xft.xrdb
%{_sysconfdir}/xdg/xfce4/xinitrc
%{_sysconfdir}/xdg/autostart/xscreensaver.desktop
%{_bindir}/xfce4-session
%{_bindir}/xfce4-session-logout
%{_bindir}/xfce4-session-settings
%{_bindir}/xflock4
%{_bindir}/startxfce4
%{_libdir}/xfce4
%{_datadir}/xfce
%{_datadir}/xsessions/xfce.desktop
%{_datadir}/xsessions/default.desktop
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%{_datadir}/themes/*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/*/*/*
%doc %{_mandir}/man1/xfce4-session*.1*

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxfsm-*.so.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%dir %{_includedir}/xfce4
%{_includedir}/xfce4/xfce4-session-*/
%{_libdir}/pkgconfig/xfce4-session-*.pc
%{_libdir}/libxfsm-*.so

%files branding-upstream
%defattr(-,root,root)
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-session.xml

%changelog
* Sat Dec 30 2017 seife+obs@b1-systems.com
- add xfce4-session-systemd-user-addons.patch to fix systemd-user
  services by exporting XAUTHLOCALHOSTNAME
* Mon Dec 18 2017 crrodriguez@opensuse.org
- Remove build require on xorg-x11 metapackage
- Add explicit build requires on x11 and atk.
* Mon Jul  3 2017 fvogt@suse.com
- Do not mark %%{_datadir}/xsessions/default.desktop as %%ghost,
  it needs to be installed as normal file.
* Wed May 17 2017 fvogt@suse.com
- Use update-alternatives to create default.desktop xsession (boo#1030873)
* Mon Sep 19 2016 robert@linux-source.org
- xfce4-session-Make-verbose-logging-conditional.patch:
  Make verbose logging conditional (boo#999676).
* Mon Mar 16 2015 gber@opensuse.org
- update to version 4.12.1
  - bump libxfce4ui min to 4.12.1
  - drop check for sessions file before it's written (bxo#11632)
  - translation updates
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - Remove AC_CHECK_HEADER_STDBOOL, it was only
    added in autoconf 2.69 and we dont use
    stdbool.h anyway
  - Add symlinks to the old icons (bxo#11513)
  - Rename action icon names (bxo#11513)
  - Gracefully handle the sessions dir being
    readonly (bxo#11307)
  - Add ConsoleKit2 support
  - Create scripts/xinitrc from scripts/xinitrc.in created by
    configure
  - Translation updates
* Mon Dec  1 2014 gber@opensuse.org
- update to version 4.11.1
  - Add DesktopNames to .desktop file
  - Export XDG_CURRENT_DESKTOP (Bug #11239)
  - Expand usage of xfsm_verbose for debugging
  - Don't log errors when trying to close non-existent FDs
  - Add error checking for fcntl
  - Properly print the dbus error message
  - Check the return value of select
  - atoi (argv[2]) is unsafe
  - Check the return value of gtk_tree_selection_get_selected
  - gtk_cell_renderer_text_new is never used
  - Minor Autotools Updates
  - Add fallback DragonflyBSD support for suspend/hibernate
  - Use pkexec for xfsm-shutdown (Bug 9952)
  - Handle gpg and ssh agents separately
    Patch by Mikhail Efremov
  - Non-POSIX compliant test used in startxfce4 (Bug 10828)
    Patch by seejay
  - Update copyright year (Bug 10768)
  - polkit_unix_process_new is deprecated (Bug 10793)
    Patch by Baurzhan Muftakhidinov
  - Add logind runtime detection to support suspend/hibernate
    (Bug 9952) Patch by Guido Berhoerster
  - Translation Updates
- drop obsolete
  xfce4-session-systemd-suspend-hibernate-support.patch,
  xfce4-session-set-desktop-name.patch,
  xfce4-session-4.10.1-fix-bashisms.patch
* Mon Oct 20 2014 gber@opensuse.org
- fix typo in xfce4-session-set-desktop-name.patch.changes,
  DesktopNames instead of DesktopName
* Sun Oct 19 2014 Led <ledest@gmail.com>
- fix bashisms in startxfce4 script (bxo#10828)
- add patches:
  * xfce4-session-4.10.1-fix-bashisms.patch (backported from
    upstream git)
* Sun Oct 19 2014 gber@opensuse.org
- add xfce4-session-set-desktop-name.patch.changes in order to set
  the DesktopName property in the xsession file (bxo#11239)
* Sun Oct 19 2014 gber@opensuse.org
- modify xfce4-session-adapt-session-scripts.patch to set
  XDG_CURRENT_DESKTOP (bxo#11239)
* Thu May  1 2014 gber@opensuse.org
- update to version 4.11.0
  - remove gnome-keyring remains
  - remove xfce environment functions and use glib
  - add shutdown/reboot functionality for systemd (bxo#8729)
  - fix duplicated accelerators
  - use the async spawn function of glib
  - store the watch function id to avoid possible double free
    (bxo#9709)
  - translation updates
* Thu Oct 10 2013 rmilasan@suse.com
- Add requires iceauth package. xfce4-session uses iceauth for
  authorization (bnc#845264).
* Tue Aug  6 2013 gber@opensuse.org
- add xfce4-session-systemd-suspend-hibernate-support.patch in
  order to add systemd suspend/hibernate support (bnc#9952)
* Fri Jun  7 2013 gber@opensuse.org
- drop obsolete configure switches
* Sun May  5 2013 gber@opensuse.org
- update to version 4.10.1
  - remove xfce environment functions and use glib
  - add shutdown/reboot functionality for systemd
  - fix logic of the --fast action
  - bump copyright year
  - store the child watch id to avoid possible double free
  - use the async spawn function of glib
  - autotools updates
  - remove gnome-keyring remains
  - handle multiple interactive session save
  - translation updates
- remove obsolete xfce4-session-avoid-possible-double-free.patch,
  xfce4-session-handle-multiple-interactive-session-save.patch
* Mon Apr 29 2013 gber@opensuse.org
- add xfce4-session-avoid-possible-double-free.patch in order to
  avoid a possible double free crash (bxo#9709, backported from
  upstream git)
* Tue Feb 26 2013 gber@opensuse.org
- removed systemd workaround in
  xfce4-session-adapt-session-scripts.patch now that
  xfce4-power-manager is patched
* Tue Dec 18 2012 gber@opensuse.org
- changed xfce4-session-adapt-session-scripts.patch so that it the
  session is wrapped with systemd-inhibit in order to work around
  systemd's broken defaults of handling suspend/hibernate-keys and
  the lidswitch which interferes with xfce4-power-manager
  (bnc#789057), this unconditionally disables systemd's handling of
  these keys regardless of its settings or whether
  xfce4-power-manager actually runs in the session or not
* Fri Sep 28 2012 gber@opensuse.org
- explicitly depend on ConsoleKit-x11 which is used via DBus
* Fri Aug 31 2012 gber@opensuse.org
- add xfce4-session-handle-multiple-interactive-session-save.patch
  in order to handle multiple interactive session save correctly,
  this should fix a lot of cases where xfwm4 was not saved and
  thus missing in the next session (bxo#5379)
* Fri Aug 31 2012 gber@opensuse.org
- add build dependency on libICE and iceauth in order to fix the
  build on Factory
* Wed May 16 2012 gber@opensuse.org
- renamed xfce4-session-adapt-session-script.patch to
  xfce4-session-adapt-session-script.patch
  - remove bashisms from xinitrc
  - do not modify XDG_CONFIG_DIRS and XDG_DATA_DIRS unless
    necessary in startxfce4
  - deliver %%{_datadir}/xfce and add it to XDG_DATA_DIRS before
    %%{_datadir} to allow for Xfce-specific defaults
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - remove remaining code to shutdown gconf
  - skip gpg/ssh-agent if GNOME compat is enabled and gnome-keyring
    found
  - replace mkdirhier with mkdir
  - translation updates
* Fri Apr 20 2012 gber@opensuse.org
- update to version 4.9.2
  - make the buttons sensitive when using sudo
  - restore ssh and gpg agent starting
  - translation updates
* Thu Apr 19 2012 gber@opensuse.org
- obsolete all xfce-utils subpackages packages properly
- obsolete xfce4-session-doc as well
* Thu Apr 19 2012 gber@opensuse.org
- change license to GPL-2.0 (bnc#758033)
* Thu Apr 19 2012 gber@opensuse.org
- let -devel depend on libxfsm-4_6-0 rather than the main package
* Sat Apr 14 2012 gber@opensuse.org
- removed leftover dependency on xfce-utils
- recommend a minimal selection of packages for a Xfce session
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.1
  - fix return value of CanSuspend and CanHibernate
  - make common no-reply error more subtile
  - bump package dependency versions
  - remove deprecated or unused code from xinit
  - fallback to old method for shutdown
  - improve xflock4 script
  - drop the sync code because it can segfault on ext2
  - always escape name and comment in dialog
  - translation updates
- drop xflock4.sh which has been included upstream
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.0
  - add accelerators to logout dialog buttons
  - add support for starting assistive technologies
  - remove optional dependency for gconf
  - remove Xfce4-tips
  - remove early xfsettingsd autostart and add it to the session
  - fix crash if save timeout for a client is triggered
  - add a way to delete sessions
  - drop usage of G_CONST_RETURN macro
  - add Xft.xrdb, startxfce4, xinit, xfce.desktop and xflock4
    files from xfce-utils
  - explicitly link to libm where needed
  - remove the xfce4-panel logout menu plugin
  - don't try to remove the $HOME directory
  - remove manual and link to docs.xfce.org
  - Show dialog in settings category
  - link to gmodule
  - improve fadeout code with compositing enabled
  - start screensaver with autostart
  - support the TryExec key for autostart in the settings dialog
  - rework the logout dialog code
  - cleanup the power management code
  - let xfce4-session handle the dbus-launch checking
  - add support for launching xfce4-session in consolekit
  - add --with-ck-launch support to startxfce4
  - add option to lock the screen on suspend/hibernate
  - remove unused icons
  - show all applications in autostart
  - drop gpg-agent and ssh-agent handling
  - translation updates
- dropped xfce4-session-fix-gnome-mode.patch since upstream
  provides an improved implementation
- dropped obsolete
  xfce4-session-respect-session-save-setting.patch,
  xfce4-session-lock-screen-on-suspend-hibernate.patch
- added xfce4-session-adapt-session-script.patch in order to adapt
  the upstream sessions script to openSUSE
* Fri Mar 30 2012 gber@opensuse.org
- specfile cleanup
- corrected dependencies
- split off libxfsm-4_6-0, -doc and -lang subpackages
- added xfce4-session-respect-session-save-setting.patch in order
  to respect the value of the "/general/SaveOnExit" option from
  xfce4-session in the logout panel plugin as well (bxo#7915)
* Mon Feb 20 2012 gber@opensuse.org
- added missing build dependency on libSM-devel
* Sun Feb 12 2012 gber@opensuse.org
- update to version 4.8.3
  - link to gmodule
  - translation updates
- dropped obsolete xfce4-session-fix-libgmodule-underlinking.patch
* Fri Jan 13 2012 gber@opensuse.org
- added xfce4-session-fix-libgmodule-underlinking.patch in order to
  explicitly link against libgmodule
* Thu Dec 15 2011 gber@opensuse.org
- improve xfce4-session-lock-screen-on-suspend-hibernate.patch and
  only lock the screen if xfce4-power-manager is configured to do
  so and execute xflock4 synchronously
* Wed Dec 14 2011 gber@opensuse.org
- added xfce4-session-lock-screen-on-suspend-hibernate.patch in
  order to try to locking the screen when hibernating/suspending
  (bxo#6019)
* Sun Nov 13 2011 gber@opensuse.org
- fixed xfce4-session-fix-gnome-mode.patch to prevent NULL pointer
  dereference on invalid autostart files (bnc#730059)
* Fri Oct 21 2011 gber@opensuse.org
- install HTML documentation under
  /usr/share/xfce4/xfce4-session/html
* Sat Oct  8 2011 gber@opensuse.org
- added xfce4-session-fix-gnome-mode.patch which removes obsolete
  GNOME compatibility code, treats GNOME-/KDE-only autostart files
  as inactive, and allows to enable them through
  xfce4-session-settings (bnc#710038, bxo#8014)
* Mon Sep 19 2011 gber@opensuse.org
- update to version 4.8.2
  - drop usage of G_CONST_RETURN macro
  - don't exit the session on dbus restarts
  - start KDE4 services instead of KDE3
  - reduce size of splash engines
  - remove the nopreview image
  - add Greek manual screenshots
  - on installation create relative paths in symlinks to images
  - only perform hostname checks when TCP connections are enabled
  - bugfixes
  - translation updates
- dropped obsolete xfce4-session-4.8.1-fix-gdm_lang-usage.patch,
  xfce4-session-4.8.1-disable-hostname-check.patch
* Tue Jul 26 2011 gber@opensuse.org
- added xfce4-session-4.8.1-disable-hostname-check.patch so
  hostname checks are only performed when TCP connections are
  enabled
* Tue May 17 2011 gber@opensuse.org
- added xfce4-session-4.8.1-fix-gdm_lang-usage.patch which fixes
  GDM_LANG usage to be compatible with GDM3 (bnc#694203, bxo#7400)
* Fri Apr  1 2011 gber@opensuse.org
- update to version 4.8.1
  - added missing license information
  - bugfixes
  - translation updates
- dropped obsolete
  xfce4-session-4.8.0-do-not-fall-back-to-system-icons.patch,
  xfce4-session-4.8.0-fix-error-popup-on-session-menu-item.patch,
  xfce4-session-4.8.0-fix-fast-cli-option.patch, and
  xfce4-session-4.7.1-fix-missing-include.patch
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb  3 2011 gber@opensuse.org
- added xfce4-session-4.8.0-fix-fast-cli-option.patch which fixes
  the use of the --fast cli option with other options
- added
  xfce4-session-4.8.0-fix-error-popup-on-session-menu-item.patch
  which fixes the error popup when clicking a session menu item
- added xfce4-session-4.8.0-do-not-fall-back-to-system-icons.patch
  in order to prevent visual inconsistencies in the logout dialog
* Wed Feb  2 2011 gber@opensuse.org
- added xfce4-session-simple-splash-remove-shadows.patch which
  improves readability of the simple splash engine text by removing
  the text shadows
- enabled support for GNOME keyring and assistive technologies
- generate documentation
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.8
  - bugfixes
* Tue Jan 11 2011 gber@opensuse.org
- removed dependency on xfconf
* Wed Jan  5 2011 gber@opensuse.org
- use consistent wording for branding packages
* Mon Dec 27 2010 gber@opensuse.org
- show compiler output
* Mon Dec 27 2010 gber@opensuse.org
- use %%%%suse_update_desktop_file for files in /etc/xdg/autostart
* Mon Dec 27 2010 gber@opensuse.org
- fixed typo
* Mon Dec 27 2010 gber@opensuse.org
- add proper BRAND comment
* Mon Dec 27 2010 gber@opensuse.org
- correct url, groups
- improve summaries/descriptions
- remove unsupported locales
- do not install documentation in /usr/share/doc
- moved xfce4-tips-autostart.desktop into the branding supackage in
  order to allow disabling startup tips as part of the branding
- remove all libtool files
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.2
  - Do not try "unix-session" authorization with PolicyKit as this
    seems to be either broken or not implemented in PolicyKit (bug #6817).
    This fixes suspend/hibernate in xfce4-session-logout.
  - Fix possibly shadowed variables.
  - Fix compilation on FreeBSD with polkit (bug #6870).
  - Restore splash screen functionality (bug #6831).
  - Fix logout with sudo.
  - Translation updates (de, pt_BR, zh_CN, el, uk, it, id, ja, kk, pt).
  - Do not try "unix-session" authorization with PolicyKit as this
    seems to be either broken or not implemented in PolicyKit (bug #6817).
    This fixes suspend/hibernate in xfce4-session-logout.
  - Fix possibly shadowed variables.
  - Fix compilation on FreeBSD with polkit (bug #6870).
  - Restore splash screen functionality (bug #6831).
  - Fix logout with sudo.
  - Translation updates (de, pt_BR, zh_CN, el, uk, it, id, ja, kk, pt).
* Fri Dec  3 2010 gber@opensuse.org
- require xfce4-utils
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Fri Nov 26 2010 gber@opensuse.org
- added xfce4-session-4.7.1-fix-missing-include.patch to fix
  missing include
* Sun Jul 18 2010 bernhard@bwalle.de
- updated to 4.6.2
  o Build fixes for GIT.
  o Add timing information to verbose output.
  o If it looks like the helper got killed, just return success (bug #4849).
  o Translation updates (de, es, gl, hu, id, pl, pt, ru, tr, uk, ro,
    lv, ur, ur_PK, ast, sk, nl, it, kk).
- Drop xfce4-session-logout-de.diff: Upstream.
* Thu May 13 2010 bernhard@bwalle.de
- Fix invalid character in the logout dialog in the German
  translation which lead Gtk to not interpret the markup. Instead,
  the raw markup code was displayed.
* Thu Mar 18 2010 prusnak@suse.cz
- build branding subpackage as noarch
* Thu Dec 10 2009 aj@suse.de
- Remove unused BuildRequires hal-devel
* Mon Apr 27 2009 prusnak@suse.cz
- updated to 4.6.1
  * Fix crash in settings dialog when a .desktop file with a missing
    Application key is opened (bug 5020).
  * Ensure networked session handling over TCP is disabled by
    default (bug 5126).
* Mon Mar  2 2009 prusnak@suse.cz
- xfce4-tips prints tips without calling fortune (tips-no-fortune.patch)
* Wed Jan 28 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Nov 18 2008 pnemec@suse.cz
- call update_desktop_file macro on desktop files [bnc#445722]
* Fri Nov 14 2008 prusnak@suse.cz
- updated suspend_hibernate.patch and renamed to logout-dialog
  * adds switch user button, only works with gdm
- fixed crash in autostart-editor (autostart-editor-crash.patch)
* Wed Oct 29 2008 bwalle@suse.de
- update to 4.4.3
  * translation polish
  * added icons
* Thu Aug 21 2008 prusnak@suse.cz
- added patch for parallel start (faster-start.patch)
* Tue Dec  4 2007 prusnak@suse.cz
- use %%find_lang macro
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.2
  o Updated and new translations
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/XFCE'
* Tue May 22 2007 prusnak@suse.cz
- include 3 files to package
- sync with BuildService
* Sun Apr 15 2007 bwalle@suse.de
- fix build
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1 (no upstream changelog for this subpackage)
* Sat Mar  3 2007 aj@suse.de
- /etc/xdg/autostart is part of filesystem now.
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
* Wed Feb  8 2006 pnemec@suse.cz
- added xfce4-desktop and xfwm to requires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 cthiel@suse.de
- really update to 4.2.3
* Mon Jan 16 2006 pnemec@suse.cz
- update to 4.2.3
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Mon Aug  1 2005 cthiel@suse.de
- fixed Requires
* Wed May 18 2005 cthiel@suse.de
- update to 4.2.2
* Tue Apr 12 2005 cthiel@suse.de
- initial version
